@@ -25,7 +25,9 @@ def setup_logging(config: dict[str, Any]) -> None:
     log_formatter = logging.Formatter(logging.BASIC_FORMAT)
     root_logger = logging.getLogger()
 
-    file_handler = logging.FileHandler(Path(config['output_folder']) / 'churn.log')
+    out = Path(config['output_folder'])
+    out.mkdir(parents=True, exist_ok=True)
+    file_handler = logging.FileHandler(out / 'churn.log')
     file_handler.setFormatter(log_formatter)
     root_logger.addHandler(file_handler)
 
